@@ -38,8 +38,6 @@ extern int no_such_variable
 #endif
 #endif
 
-extern char *nls_date_format;
-
 /* from aggregate.c */
 extern PGDLLEXPORT Datum orafce_listagg1_transfn(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum orafce_listagg2_transfn(PG_FUNCTION_ARGS);
@@ -77,6 +75,7 @@ extern PGDLLEXPORT Datum orafce_to_char_numeric(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum orafce_to_char_timestamp(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum orafce_to_number(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum orafce_to_multi_byte(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum orafce_to_single_byte(PG_FUNCTION_ARGS);
 
 /* from datefce.c */
 extern PGDLLEXPORT Datum next_day(PG_FUNCTION_ARGS);
@@ -89,6 +88,9 @@ extern PGDLLEXPORT Datum ora_date_trunc(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum ora_date_round(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum ora_timestamptz_trunc(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum ora_timestamptz_round(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum orafce_sysdate(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum orafce_sessiontimezone(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum orafce_dbtimezone(PG_FUNCTION_ARGS);
 
 /* from file.c */
 extern PGDLLEXPORT Datum utl_file_fopen(PG_FUNCTION_ARGS);
@@ -254,9 +256,23 @@ extern PGDLLEXPORT Datum dbms_utility_format_call_stack1(PG_FUNCTION_ARGS);
 extern void PGDLLEXPORT _PG_init(void);
 
 /* from charpad.c */
-extern PGDLLEXPORT Datum lpad(PG_FUNCTION_ARGS);
-extern PGDLLEXPORT Datum rpad(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum orafce_lpad(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum orafce_rpad(PG_FUNCTION_ARGS);
 
 /* from charlen.c */
-extern PGDLLEXPORT Datum bpcharlen(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum orafce_bpcharlen(PG_FUNCTION_ARGS);
+
+/* from varchar2.c */
+extern PGDLLEXPORT Datum varchar2in(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum varchar2out(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum varchar2(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum varchar2typmodin(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum varchar2recv(PG_FUNCTION_ARGS);
+
+/* from nvarchar2.c */
+extern PGDLLEXPORT Datum nvarchar2in(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum nvarchar2out(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum nvarchar2(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum nvarchar2typmodin(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum nvarchar2recv(PG_FUNCTION_ARGS);
 #endif
