@@ -12,9 +12,8 @@
 #include "mb/pg_wchar.h"
 #include "fmgr.h"
 
-#ifndef PG_MODULE_MAGIC
-PG_MODULE_MAGIC;
-#endif
+#include "orafce.h"
+#include "builtins.h"
 
 /* flags */
 #define ON	true
@@ -23,21 +22,17 @@ PG_MODULE_MAGIC;
 /* Upper limit on total width of the padded output of *pad functions */
 #define PAD_MAX 4000
 
-/* Prototype declarations */
-extern Datum lpad(PG_FUNCTION_ARGS);
-extern Datum rpad(PG_FUNCTION_ARGS);
-
-PG_FUNCTION_INFO_V1(lpad);
-PG_FUNCTION_INFO_V1(rpad);
+PG_FUNCTION_INFO_V1(orafce_lpad);
+PG_FUNCTION_INFO_V1(orafce_rpad);
 
 /*
- * lpad(string text, length int32 [, fill text])
+ * orafce_lpad(string text, length int32 [, fill text])
  *
  * Fill up the string to length 'length' by prepending
  * the characters fill (a half-width space by default)
  */
 Datum
-lpad(PG_FUNCTION_ARGS)
+orafce_lpad(PG_FUNCTION_ARGS)
 {
 	text	*string1 = PG_GETARG_TEXT_PP(0);
 	int32	output_width = PG_GETARG_INT32(1);
@@ -45,8 +40,8 @@ lpad(PG_FUNCTION_ARGS)
 	text	*ret;
 	char	*ptr1,
 			*ptr2,
-			*ptr2start,
-			*ptr2end,
+			*ptr2start = NULL,
+			*ptr2end = NULL,
 			*ptr_ret,
 			*spc = " ";
 	int		mlen,
@@ -149,8 +144,8 @@ lpad(PG_FUNCTION_ARGS)
 		/* remaining part of output_width is composed of string2 */
 		s2_add_width = output_width - s1_width;
 
-	    ptr2 = ptr2start = VARDATA_ANY(string2);
-    	ptr2end = ptr2 + s2blen;
+		ptr2 = ptr2start = VARDATA_ANY(string2);
+		ptr2end = ptr2 + s2blen;
 
 		while (s2_add_width > 0)
 		{
@@ -261,13 +256,13 @@ lpad(PG_FUNCTION_ARGS)
 }
 
 /*
- * rpad(string text, length int32 [, fill text])
+ * orafce_rpad(string text, length int32 [, fill text])
  *
  * Fill up the string to length 'length' by appending
  * the characters fill (a half-width space by default)
  */
 Datum
-rpad(PG_FUNCTION_ARGS)
+orafce_rpad(PG_FUNCTION_ARGS)
 {
 	text	*string1 = PG_GETARG_TEXT_PP(0);
 	int32	output_width = PG_GETARG_INT32(1);
@@ -275,8 +270,8 @@ rpad(PG_FUNCTION_ARGS)
 	text	*ret;
 	char	*ptr1,
 			*ptr2,
-			*ptr2start,
-			*ptr2end,
+			*ptr2start = NULL,
+			*ptr2end = NULL,
 			*ptr_ret,
 			*spc = " ";
 	int		mlen,
@@ -379,8 +374,8 @@ rpad(PG_FUNCTION_ARGS)
 		/* remaining part of output_width is composed of string2 */
 		s2_add_width = output_width - s1_width;
 
-	    ptr2 = ptr2start = VARDATA_ANY(string2);
-    	ptr2end = ptr2 + s2blen;
+		ptr2 = ptr2start = VARDATA_ANY(string2);
+		ptr2end = ptr2 + s2blen;
 
 		while (s2_add_width > 0)
 		{
