@@ -1,4 +1,4 @@
-/* contrib/orafce--3.0.sql */
+/* contrib/orafce--3.2.sql */
 
 -- complain if script is sourced in psql, rather than via CREATE EXTENSION
 \echo Use "CREATE EXTENSION orafce" to load this file. \quit
@@ -181,6 +181,12 @@ AS 'MODULE_PATHNAME','orafce_to_multi_byte'
 LANGUAGE C IMMUTABLE STRICT;
 COMMENT ON FUNCTION to_multi_byte(text) IS 'Convert all single-byte characters to their corresponding multibyte characters';
 
+CREATE FUNCTION to_single_byte(str text)
+RETURNS text
+AS 'MODULE_PATHNAME','orafce_to_single_byte'
+LANGUAGE C IMMUTABLE STRICT;
+COMMENT ON FUNCTION to_single_byte(text) IS 'Convert characters to their corresponding single-byte characters if possible';
+
 CREATE FUNCTION bitand(bigint, bigint)
 RETURNS bigint
 AS $$ SELECT $1 & $2; $$
@@ -216,12 +222,27 @@ RETURNS numeric AS
 $$ SELECT CASE WHEN $1 = 'NaN' THEN $2 ELSE $1 END; $$
 LANGUAGE sql IMMUTABLE STRICT;
 
-CREATE FUNCTION dump("any") 
+CREATE FUNCTION nanvl(float4, varchar)
+RETURNS float4 AS
+$$ SELECT CASE WHEN $1 = 'NaN' THEN $2::float4 ELSE $1 END; $$
+LANGUAGE sql IMMUTABLE STRICT;
+
+CREATE FUNCTION nanvl(float8, varchar)
+RETURNS float8 AS
+$$ SELECT CASE WHEN $1 = 'NaN' THEN $2::float8 ELSE $1 END; $$
+LANGUAGE sql IMMUTABLE STRICT;
+
+CREATE FUNCTION nanvl(numeric, varchar)
+RETURNS numeric AS
+$$ SELECT CASE WHEN $1 = 'NaN' THEN $2::numeric ELSE $1 END; $$
+LANGUAGE sql IMMUTABLE STRICT;
+
+CREATE FUNCTION dump("any")
 RETURNS varchar
 AS 'MODULE_PATHNAME', 'orafce_dump'
 LANGUAGE C;
 
-CREATE FUNCTION dump("any", integer) 
+CREATE FUNCTION dump("any", integer)
 RETURNS varchar
 AS 'MODULE_PATHNAME', 'orafce_dump'
 LANGUAGE C;
@@ -432,6 +453,24 @@ AS 'MODULE_PATHNAME','orafce_to_char_timestamp'
 LANGUAGE C STABLE STRICT;
 COMMENT ON FUNCTION oracle.to_char(timestamp) IS 'Convert timestamp to string';
 
+CREATE FUNCTION oracle.sysdate()
+RETURNS oracle.date
+AS 'MODULE_PATHNAME','orafce_sysdate'
+LANGUAGE C STABLE STRICT;
+COMMENT ON FUNCTION oracle.sysdate() IS 'Ruturns statement timestamp at server time zone';
+
+CREATE FUNCTION oracle.sessiontimezone()
+RETURNS text
+AS 'MODULE_PATHNAME','orafce_sessiontimezone'
+LANGUAGE C STABLE STRICT;
+COMMENT ON FUNCTION oracle.sessiontimezone() IS 'Ruturns session time zone';
+
+CREATE FUNCTION oracle.dbtimezone()
+RETURNS text
+AS 'MODULE_PATHNAME','orafce_dbtimezone'
+LANGUAGE C STABLE STRICT;
+COMMENT ON FUNCTION oracle.sessiontimezone() IS 'Ruturns server time zone (orafce.timezone)';
+
 -- emulation of dual table
 CREATE VIEW public.dual AS SELECT 'X'::varchar AS dummy;
 REVOKE ALL ON public.dual FROM PUBLIC;
@@ -502,7 +541,6 @@ CREATE FUNCTION nvl(anyelement, anyelement)
 RETURNS anyelement
 AS 'MODULE_PATHNAME','ora_nvl'
 LANGUAGE C IMMUTABLE;
-COMMENT ON FUNCTION nvl(anyelement, anyelement) IS '';
 
 CREATE FUNCTION nvl2(anyelement, anyelement, anyelement)
 RETURNS anyelement
@@ -1893,7 +1931,7 @@ COMMENT ON FUNCTION plunit.fail(message varchar) IS 'Immediately fail.';
 CREATE SCHEMA dbms_random;
 
 CREATE FUNCTION dbms_random.initialize(int)
-RETURNS void 
+RETURNS void
 AS 'MODULE_PATHNAME','dbms_random_initialize'
 LANGUAGE C IMMUTABLE STRICT;
 COMMENT ON FUNCTION dbms_random.initialize(int) IS 'Initialize package with a seed value';
@@ -1911,13 +1949,13 @@ LANGUAGE C VOLATILE;
 COMMENT ON FUNCTION dbms_random.random() IS 'Generate Random Numeric Values';
 
 CREATE FUNCTION dbms_random.seed(integer)
-RETURNS void 
+RETURNS void
 AS 'MODULE_PATHNAME','dbms_random_seed_int'
 LANGUAGE C IMMUTABLE STRICT;
 COMMENT ON FUNCTION dbms_random.seed(int) IS 'Reset the seed value';
 
 CREATE FUNCTION dbms_random.seed(text)
-RETURNS void 
+RETURNS void
 AS 'MODULE_PATHNAME','dbms_random_seed_varchar'
 LANGUAGE C IMMUTABLE STRICT;
 COMMENT ON FUNCTION dbms_random.seed(text) IS 'Reset the seed value';
@@ -1929,7 +1967,7 @@ LANGUAGE C IMMUTABLE;
 COMMENT ON FUNCTION dbms_random.string(text,int) IS 'Create Random Strings';
 
 CREATE FUNCTION dbms_random.terminate()
-RETURNS void 
+RETURNS void
 AS 'MODULE_PATHNAME','dbms_random_terminate'
 LANGUAGE C IMMUTABLE;
 COMMENT ON FUNCTION dbms_random.terminate() IS 'Terminate use of the Package';
@@ -1941,17 +1979,17 @@ LANGUAGE C STRICT VOLATILE;
 COMMENT ON FUNCTION dbms_random.value(double precision, double precision) IS 'Generate Random number x, where x is greather or equal to low and less then high';
 
 CREATE FUNCTION dbms_random.value()
-RETURNS double precision 
+RETURNS double precision
 AS 'MODULE_PATHNAME','dbms_random_value'
 LANGUAGE C VOLATILE;
 COMMENT ON FUNCTION dbms_random.value() IS 'Generate Random number x, where x is greather or equal to 0 and less then 1';
 
-CREATE FUNCTION dump(text) 
+CREATE FUNCTION dump(text)
 RETURNS varchar
 AS 'MODULE_PATHNAME', 'orafce_dump'
 LANGUAGE C;
 
-CREATE FUNCTION dump(text, integer) 
+CREATE FUNCTION dump(text, integer)
 RETURNS varchar
 AS 'MODULE_PATHNAME', 'orafce_dump'
 LANGUAGE C;
@@ -1969,12 +2007,12 @@ LANGUAGE SQL VOLATILE;
 COMMENT ON FUNCTION utl_file.put_line(utl_file.file_type, anyelement, bool) IS 'Puts data to specified file and append newline character';
 
 CREATE FUNCTION pg_catalog.listagg1_transfn(internal, text)
-RETURNS internal 
+RETURNS internal
 AS 'MODULE_PATHNAME','orafce_listagg1_transfn'
 LANGUAGE C IMMUTABLE;
 
 CREATE FUNCTION pg_catalog.listagg2_transfn(internal, text, text)
-RETURNS internal 
+RETURNS internal
 AS 'MODULE_PATHNAME','orafce_listagg2_transfn'
 LANGUAGE C IMMUTABLE;
 
@@ -1984,14 +2022,14 @@ AS 'MODULE_PATHNAME','orafce_listagg_finalfn'
 LANGUAGE C IMMUTABLE;
 
 CREATE AGGREGATE pg_catalog.listagg(text) (
-  SFUNC=pg_catalog.listagg1_transfn, 
-  STYPE=internal, 
+  SFUNC=pg_catalog.listagg1_transfn,
+  STYPE=internal,
   FINALFUNC=pg_catalog.listagg_finalfn
 );
 
 CREATE AGGREGATE pg_catalog.listagg(text, text) (
-  SFUNC=pg_catalog.listagg2_transfn, 
-  STYPE=internal, 
+  SFUNC=pg_catalog.listagg2_transfn,
+  STYPE=internal,
   FINALFUNC=pg_catalog.listagg_finalfn
 );
 
@@ -2016,14 +2054,14 @@ AS 'MODULE_PATHNAME','orafce_median8_finalfn'
 LANGUAGE C IMMUTABLE;
 
 CREATE AGGREGATE pg_catalog.median(real) (
-  SFUNC=pg_catalog.median4_transfn, 
-  STYPE=internal, 
+  SFUNC=pg_catalog.median4_transfn,
+  STYPE=internal,
   FINALFUNC=pg_catalog.median4_finalfn
 );
 
 CREATE AGGREGATE pg_catalog.median(double precision) (
-  SFUNC=pg_catalog.median8_transfn, 
-  STYPE=internal, 
+  SFUNC=pg_catalog.median8_transfn,
+  STYPE=internal,
   FINALFUNC=pg_catalog.median8_finalfn
 );
 
@@ -2419,28 +2457,28 @@ WHERE proname='nvarchar2';
  */
 CREATE FUNCTION oracle.lpad(char, integer, char)
 RETURNS text
-AS 'MODULE_PATHNAME','lpad'
+AS 'MODULE_PATHNAME','orafce_lpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.lpad(char, integer, text)
 RETURNS text
-AS 'MODULE_PATHNAME','lpad'
+AS 'MODULE_PATHNAME','orafce_lpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.lpad(char, integer, varchar2)
 RETURNS text
-AS 'MODULE_PATHNAME','lpad'
+AS 'MODULE_PATHNAME','orafce_lpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.lpad(char, integer, nvarchar2)
 RETURNS text
-AS 'MODULE_PATHNAME','lpad'
+AS 'MODULE_PATHNAME','orafce_lpad'
 LANGUAGE 'c'
 STRICT
 ;
@@ -2454,42 +2492,42 @@ STRICT
 
 CREATE FUNCTION oracle.lpad(text, integer, char)
 RETURNS text
-AS 'MODULE_PATHNAME','lpad'
+AS 'MODULE_PATHNAME','orafce_lpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.lpad(varchar2, integer, char)
 RETURNS text
-AS 'MODULE_PATHNAME','lpad'
+AS 'MODULE_PATHNAME','orafce_lpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.lpad(nvarchar2, integer, char)
 RETURNS text
-AS 'MODULE_PATHNAME','lpad'
+AS 'MODULE_PATHNAME','orafce_lpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.lpad(text, integer, text)
 RETURNS text
-AS 'MODULE_PATHNAME','lpad'
+AS 'MODULE_PATHNAME','orafce_lpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.lpad(text, integer, varchar2)
 RETURNS text
-AS 'MODULE_PATHNAME','lpad'
+AS 'MODULE_PATHNAME','orafce_lpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.lpad(text, integer, nvarchar2)
 RETURNS text
-AS 'MODULE_PATHNAME','lpad'
+AS 'MODULE_PATHNAME','orafce_lpad'
 LANGUAGE 'c'
 STRICT
 ;
@@ -2503,21 +2541,21 @@ STRICT
 
 CREATE FUNCTION oracle.lpad(varchar2, integer, text)
 RETURNS text
-AS 'MODULE_PATHNAME','lpad'
+AS 'MODULE_PATHNAME','orafce_lpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.lpad(varchar2, integer, varchar2)
 RETURNS text
-AS 'MODULE_PATHNAME','lpad'
+AS 'MODULE_PATHNAME','orafce_lpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.lpad(varchar2, integer, nvarchar2)
 RETURNS text
-AS 'MODULE_PATHNAME','lpad'
+AS 'MODULE_PATHNAME','orafce_lpad'
 LANGUAGE 'c'
 STRICT
 ;
@@ -2531,21 +2569,21 @@ STRICT
 
 CREATE FUNCTION oracle.lpad(nvarchar2, integer, text)
 RETURNS text
-AS 'MODULE_PATHNAME','lpad'
+AS 'MODULE_PATHNAME','orafce_lpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.lpad(nvarchar2, integer, varchar2)
 RETURNS text
-AS 'MODULE_PATHNAME','lpad'
+AS 'MODULE_PATHNAME','orafce_lpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.lpad(nvarchar2, integer, nvarchar2)
 RETURNS text
-AS 'MODULE_PATHNAME','lpad'
+AS 'MODULE_PATHNAME','orafce_lpad'
 LANGUAGE 'c'
 STRICT
 ;
@@ -2570,28 +2608,28 @@ STRICT
  */
 CREATE FUNCTION oracle.rpad(char, integer, char)
 RETURNS text
-AS 'MODULE_PATHNAME','rpad'
+AS 'MODULE_PATHNAME','orafce_rpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.rpad(char, integer, text)
 RETURNS text
-AS 'MODULE_PATHNAME','rpad'
+AS 'MODULE_PATHNAME','orafce_rpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.rpad(char, integer, varchar2)
 RETURNS text
-AS 'MODULE_PATHNAME','rpad'
+AS 'MODULE_PATHNAME','orafce_rpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.rpad(char, integer, nvarchar2)
 RETURNS text
-AS 'MODULE_PATHNAME','rpad'
+AS 'MODULE_PATHNAME','orafce_rpad'
 LANGUAGE 'c'
 STRICT
 ;
@@ -2605,42 +2643,42 @@ STRICT
 
 CREATE FUNCTION oracle.rpad(text, integer, char)
 RETURNS text
-AS 'MODULE_PATHNAME','rpad'
+AS 'MODULE_PATHNAME','orafce_rpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.rpad(varchar2, integer, char)
 RETURNS text
-AS 'MODULE_PATHNAME','rpad'
+AS 'MODULE_PATHNAME','orafce_rpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.rpad(nvarchar2, integer, char)
 RETURNS text
-AS 'MODULE_PATHNAME','rpad'
+AS 'MODULE_PATHNAME','orafce_rpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.rpad(text, integer, text)
 RETURNS text
-AS 'MODULE_PATHNAME','rpad'
+AS 'MODULE_PATHNAME','orafce_rpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.rpad(text, integer, varchar2)
 RETURNS text
-AS 'MODULE_PATHNAME','rpad'
+AS 'MODULE_PATHNAME','orafce_rpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.rpad(text, integer, nvarchar2)
 RETURNS text
-AS 'MODULE_PATHNAME','rpad'
+AS 'MODULE_PATHNAME','orafce_rpad'
 LANGUAGE 'c'
 STRICT
 ;
@@ -2654,21 +2692,21 @@ STRICT
 
 CREATE FUNCTION oracle.rpad(varchar2, integer, text)
 RETURNS text
-AS 'MODULE_PATHNAME','rpad'
+AS 'MODULE_PATHNAME','orafce_rpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.rpad(varchar2, integer, varchar2)
 RETURNS text
-AS 'MODULE_PATHNAME','rpad'
+AS 'MODULE_PATHNAME','orafce_rpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.rpad(varchar2, integer, nvarchar2)
 RETURNS text
-AS 'MODULE_PATHNAME','rpad'
+AS 'MODULE_PATHNAME','orafce_rpad'
 LANGUAGE 'c'
 STRICT
 ;
@@ -2682,21 +2720,21 @@ STRICT
 
 CREATE FUNCTION oracle.rpad(nvarchar2, integer, text)
 RETURNS text
-AS 'MODULE_PATHNAME','rpad'
+AS 'MODULE_PATHNAME','orafce_rpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.rpad(nvarchar2, integer, varchar2)
 RETURNS text
-AS 'MODULE_PATHNAME','rpad'
+AS 'MODULE_PATHNAME','orafce_rpad'
 LANGUAGE 'c'
 STRICT
 ;
 
 CREATE FUNCTION oracle.rpad(nvarchar2, integer, nvarchar2)
 RETURNS text
-AS 'MODULE_PATHNAME','rpad'
+AS 'MODULE_PATHNAME','orafce_rpad'
 LANGUAGE 'c'
 STRICT
 ;
@@ -3146,7 +3184,7 @@ STRICT
 /* LENGTH */
 CREATE FUNCTION oracle.length(char)
 RETURNS integer
-AS 'MODULE_PATHNAME','bpcharlen'
+AS 'MODULE_PATHNAME','orafce_bpcharlen'
 LANGUAGE 'c'
 STRICT
 ;
