@@ -645,11 +645,7 @@ dbms_pipe_pack_message_record(PG_FUNCTION_ARGS)
 	 * using fcinfo->flinfo->fn_extra.  So we need to pass it our own
 	 * flinfo parameter.
 	 */
-#if PG_VERSION_NUM >= 90100
 	InitFunctionCallInfoData(info, fcinfo->flinfo, 3, InvalidOid, NULL, NULL);
-#else
-	InitFunctionCallInfoData(info, fcinfo->flinfo, 3, NULL, NULL);
-#endif
 
 	info.arg[0] = PointerGetDatum(rec);
 	info.arg[1] = ObjectIdGetDatum(tupType);
@@ -724,11 +720,7 @@ dbms_pipe_unpack_message(PG_FUNCTION_ARGS, message_data_type dtype)
 			 * using fcinfo->flinfo->fn_extra.  So we need to pass it our own
 			 * flinfo parameter.
 			 */
-#if PG_VERSION_NUM >= 90100
 			InitFunctionCallInfoData(info, fcinfo->flinfo, 3, InvalidOid, NULL, NULL);
-#else
-			InitFunctionCallInfoData(info, fcinfo->flinfo, 3, NULL, NULL);
-#endif
 
 			info.arg[0] = PointerGetDatum(&buf);
 			info.arg[1] = ObjectIdGetDatum(tupType);
@@ -1090,7 +1082,17 @@ dbms_pipe_create_pipe (PG_FUNCTION_ARGS)
 				char *user;
 
 				p->uid = GetUserId();
+
+#if PG_VERSION_NUM >= 90500
+
+				user = (char*)DirectFunctionCall1(namein,
+					    CStringGetDatum(GetUserNameFromId(p->uid, false)));
+
+#else
+
 				user = (char*)DirectFunctionCall1(namein, CStringGetDatum(GetUserNameFromId(p->uid)));
+#endif
+
 				p->creator = ora_sstrcpy(user);
 				pfree(user);
 			}
