@@ -25,20 +25,6 @@
 #include "orafce.h"
 #include "builtins.h"
 
-
-/*
- * External (defined in PgSQL datetime.c (timestamp utils))
- */
-#if PG_VERSION_NUM >= 90400
-#define STRING_PTR_FIELD_TYPE const char *const
-#else
-#define STRING_PTR_FIELD_TYPE char *
-#endif
-
-extern PGDLLIMPORT STRING_PTR_FIELD_TYPE days[];
-
-extern int ora_seq_search(const char *name, STRING_PTR_FIELD_TYPE array[], int max);
-
 PG_FUNCTION_INFO_V1(plvdate_add_bizdays);
 PG_FUNCTION_INFO_V1(plvdate_nearest_bizday);
 PG_FUNCTION_INFO_V1(plvdate_next_bizday);
@@ -219,7 +205,7 @@ easter_sunday(int year, int* dd, int* mm)
 	}
 }
 
-static Datum
+static DateADT
 ora_add_bizdays(DateADT day, int days)
 {
 	int d, dx;
@@ -463,7 +449,7 @@ plvdate_isbizday (PG_FUNCTION_ARGS)
 	j2date(day + POSTGRES_EPOCH_JDATE, &y, &m, &d);
 	hd.month = m; hd.day = d;
 
- 	if (use_easter && (m == 3 || m == 4))
+	if (use_easter && (m == 3 || m == 4))
 	{
 		easter_sunday(y, &d, &m);
 		if (m == hd.month && (d == hd.day || d+1 == hd.day))
@@ -493,16 +479,16 @@ plvdate_set_nonbizday_dow (PG_FUNCTION_ARGS)
 
 	text *day_txt = PG_GETARG_TEXT_PP(0);
 
-	int d = ora_seq_search(VARDATA_ANY(day_txt), days, VARSIZE_ANY_EXHDR(day_txt));
+	int d = ora_seq_search(VARDATA_ANY(day_txt), ora_days, VARSIZE_ANY_EXHDR(day_txt));
 	CHECK_SEQ_SEARCH(d, "DAY/Day/day");
 
 	check = nonbizdays | (1 << d);
 	if (check == 0x7f)
-                ereport(ERROR,
-                        (errcode(ERRCODE_DATA_EXCEPTION),
-                         errmsg("nonbizday registeration error"),
-                         errdetail("Constraint violation."),
-                         errhint("One day in week have to be bizday.")));
+		ereport(ERROR,
+			    (errcode(ERRCODE_DATA_EXCEPTION),
+			     errmsg("nonbizday registeration error"),
+			     errdetail("Constraint violation."),
+			     errhint("One day in week have to be bizday.")));
 
 	nonbizdays = nonbizdays | (1 << d);
 
@@ -525,7 +511,7 @@ plvdate_unset_nonbizday_dow (PG_FUNCTION_ARGS)
 {
 	text *day_txt = PG_GETARG_TEXT_PP(0);
 
-	int d = ora_seq_search(VARDATA_ANY(day_txt), days, VARSIZE_ANY_EXHDR(day_txt));
+	int d = ora_seq_search(VARDATA_ANY(day_txt), ora_days, VARSIZE_ANY_EXHDR(day_txt));
 	CHECK_SEQ_SEARCH(d, "DAY/Day/day");
 
 	nonbizdays = (nonbizdays | (1 << d)) ^ (1 << d);
@@ -557,20 +543,20 @@ plvdate_set_nonbizday_day (PG_FUNCTION_ARGS)
 	if (arg2)
 	{
 		if (holidays_c == MAX_holidays)
-                        ereport(ERROR,
-                                (errcode(ERRCODE_PROGRAM_LIMIT_EXCEEDED),
-                                 errmsg("nonbizday registeration error"),
-                                 errdetail("Too much registered nonbizdays."),
-                                 errhint("Increase MAX_holidays in 'plvdate.c'.")));
+			ereport(ERROR,
+				    (errcode(ERRCODE_PROGRAM_LIMIT_EXCEEDED),
+				     errmsg("nonbizday registeration error"),
+				     errdetail("Too much registered nonbizdays."),
+				     errhint("Increase MAX_holidays in 'plvdate.c'.")));
 
 		j2date(arg1 + POSTGRES_EPOCH_JDATE, &y, &m, &d);
 		hd.month = m; hd.day = d;
 
 		if (NULL != bsearch(&hd, holidays, holidays_c, sizeof(holiday_desc), holiday_desc_comp))
-                        ereport(ERROR,
-                                (errcode(ERRCODE_DUPLICATE_OBJECT),
-                                 errmsg("nonbizday registeration error"),
-                                 errdetail("Date is registered.")));
+			ereport(ERROR,
+				    (errcode(ERRCODE_DUPLICATE_OBJECT),
+				     errmsg("nonbizday registeration error"),
+				     errdetail("Date is registered.")));
 
 		holidays[holidays_c].month = m;
 		holidays[holidays_c].day = d;
@@ -581,17 +567,17 @@ plvdate_set_nonbizday_day (PG_FUNCTION_ARGS)
 	else
 	{
 		if (exceptions_c == MAX_EXCEPTIONS)
-                        ereport(ERROR,
-                                (errcode(ERRCODE_PROGRAM_LIMIT_EXCEEDED),
-                                 errmsg("nonbizday registeration error"),
-                                 errdetail("Too much registered nonrepeated nonbizdays."),
-                                 errhint("Increase MAX_EXCEPTIONS in 'plvdate.c'.")));
+			ereport(ERROR,
+				    (errcode(ERRCODE_PROGRAM_LIMIT_EXCEEDED),
+				     errmsg("nonbizday registeration error"),
+				     errdetail("Too much registered nonrepeated nonbizdays."),
+				     errhint("Increase MAX_EXCEPTIONS in 'plvdate.c'.")));
 
 		if (NULL != bsearch(&arg1, exceptions, exceptions_c, sizeof(DateADT), dateadt_comp))
-                        ereport(ERROR,
-                                (errcode(ERRCODE_DUPLICATE_OBJECT),
-                                 errmsg("nonbizday registeration error"),
-                                 errdetail("Date is registered.")));
+			ereport(ERROR,
+				    (errcode(ERRCODE_DUPLICATE_OBJECT),
+				     errmsg("nonbizday registeration error"),
+				     errdetail("Date is registered.")));
 
 		exceptions[exceptions_c++] = arg1;
 		qsort(exceptions, exceptions_c, sizeof(DateADT), dateadt_comp);
@@ -649,10 +635,10 @@ plvdate_unset_nonbizday_day (PG_FUNCTION_ARGS)
 			exceptions_c -= 1;
 	}
 	if (!found)
-                ereport(ERROR,
-                        (errcode(ERRCODE_UNDEFINED_OBJECT),
-                         errmsg("nonbizday unregisteration error"),
-                         errdetail("Nonbizday not found.")));
+		ereport(ERROR,
+			    (errcode(ERRCODE_UNDEFINED_OBJECT),
+			     errmsg("nonbizday unregisteration error"),
+			     errdetail("Nonbizday not found.")));
 
 	PG_RETURN_VOID();
 }
