@@ -522,6 +522,14 @@ SELECT nanvl(12345, 1), nanvl('NaN', 1);
 SELECT nanvl(12345::float4, 1), nanvl('NaN'::float4, 1);
 SELECT nanvl(12345::float8, 1), nanvl('NaN'::float8, 1);
 SELECT nanvl(12345::numeric, 1), nanvl('NaN'::numeric, 1);
+SELECT nanvl(12345, '1'::varchar), nanvl('NaN', 1::varchar);
+SELECT nanvl(12345::float4, '1'::varchar), nanvl('NaN'::float4, '1'::varchar);
+SELECT nanvl(12345::float8, '1'::varchar), nanvl('NaN'::float8, '1'::varchar);
+SELECT nanvl(12345::numeric, '1'::varchar), nanvl('NaN'::numeric, '1'::varchar);
+SELECT nanvl(12345, '1'::char), nanvl('NaN', 1::char);
+SELECT nanvl(12345::float4, '1'::char), nanvl('NaN'::float4, '1'::char);
+SELECT nanvl(12345::float8, '1'::char), nanvl('NaN'::float8, '1'::char);
+SELECT nanvl(12345::numeric, '1'::char), nanvl('NaN'::numeric, '1'::char);
 
 select dbms_assert.enquote_literal('some text '' some text');
 select dbms_assert.enquote_name('''"AAA');
@@ -574,6 +582,13 @@ SELECT to_multi_byte('123$test');
 SELECT octet_length('abc');
 SELECT octet_length(to_multi_byte('abc'));
 
+-- Tests for to_single_byte
+SELECT to_single_byte('123$test');
+SELECT to_single_byte('１２３＄ｔｅｓｔ');
+-- Check internal representation difference
+SELECT octet_length('ａｂｃ');
+SELECT octet_length(to_single_byte('ａｂｃ'));
+
 -- Tests for round(TIMESTAMP WITH TIME ZONE)
 select round(TIMESTAMP WITH TIME ZONE'12/08/1990 05:35:25','YEAR') = '1991-01-01 00:00:00';
 select round(TIMESTAMP WITH TIME ZONE'05/08/1990 05:35:25','Q') = '1990-04-01 00:00:00';
