@@ -17,15 +17,7 @@
 #include "fmgr.h"
 
 #include "orafce.h"
-
-
-/* prototype declarations */
-extern Datum varchar2in(PG_FUNCTION_ARGS);			/* C string to internal
-													   VARCHAR2 representation */
-extern Datum varchar2out(PG_FUNCTION_ARGS);			/* VARCHAR2 to C string */
-extern Datum varchar2(PG_FUNCTION_ARGS);			/* VARCHAR2 length check */
-extern Datum varchar2typmodin(PG_FUNCTION_ARGS);	/* type modifier internal conversion */
-extern Datum varchar2recv(PG_FUNCTION_ARGS);		/* external binary format to VARCHAR2 */
+#include "builtins.h"
 
 PG_FUNCTION_INFO_V1(varchar2in);
 PG_FUNCTION_INFO_V1(varchar2out);
@@ -70,7 +62,6 @@ varchar2_input(const char *s, size_t len, int32 atttypmod)
  * Converts a C string to VARCHAR2 internal representation.  atttypmod
  * is the declared length of the type plus VARHDRSZ.
  */
-
 Datum
 varchar2in(PG_FUNCTION_ARGS)
 {
@@ -92,7 +83,6 @@ varchar2in(PG_FUNCTION_ARGS)
  * Uses the text to C string conversion function, which is only appropriate
  * if VarChar and text are equivalent types.
  */
-
 Datum
 varchar2out(PG_FUNCTION_ARGS)
 {
@@ -104,7 +94,6 @@ varchar2out(PG_FUNCTION_ARGS)
 /*
  * converts external binary format to varchar
  */
-
 Datum
 varchar2recv(PG_FUNCTION_ARGS)
 {
